==> jboss-eap-7.0.3-src.zip: jboss-eap-7.0-src/clustering/server/src/main/java/org/wildfly/clustering/server/group/ChannelNodeFactoryBuilderProvider.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2014, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.wildfly.clustering.server.group;

import java.util.Collection;
import java.util.Collections;

import org.jboss.modules.ModuleIdentifier;
import org.wildfly.clustering.service.Builder;
import org.wildfly.clustering.spi.DistributedGroupBuilderProvider;

/**
 * Provides the requisite builders for creating a channel-based {@link org.wildfly.clustering.group.NodeFactory}.
 * @author Paul Ferraro
 */
public class ChannelNodeFactoryBuilderProvider implements DistributedGroupBuilderProvider {

    @Override
    public Collection<Builder<?>> getBuilders(String group, ModuleIdentifier module) {
        return Collections.<Builder<?>>singleton(new ChannelNodeFactoryBuilder(group));
    }

    @Override
    public String toString() {
        return this.getClass().getName();
    }
}

==> jboss-eap-7.1.0-src.zip: jboss-eap-7.1-src/clustering/server/src/main/java/org/wildfly/clustering/server/group/ChannelNodeFactoryBuilderProvider.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2014, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.wildfly.clustering.server.group;

import org.wildfly.clustering.spi.DistributedGroupBuilderProvider;

/**
 * Provides the requisite builders for creating a channel-based {@link org.wildfly.clustering.group.NodeFactory}.
 * @author Paul Ferraro
 */
public class ChannelNodeFactoryBuilderProvider extends JGroupsNodeFactoryBuilderProvider<ChannelNodeFactory> implements DistributedGroupBuilderProvider {

    public ChannelNodeFactoryBuilderProvider() {
        super((name, group) -> new ChannelNodeFactoryBuilder(name, group));
    }
}
